# Moose
Moose是一个数据处理的自动化框架，旨在提供一套快速、灵活、便捷、幂等式的数据处理方案。它不仅提供了常用的数据处理类和函数，也提供了一套命令行式的接口以处理和维护版本内单一、重复、繁琐的任务。
- - - -
## Requirements
    * Python 2.7 or Python 3.3+
    * Works on Linux, Windows, Mac OSX, BSD


## Install
The quick way:

    pip install moose

For more details see the install section in the documentation:
https://moose-datatang.readthedocs.io/zh_CN/latest/intro/install.html


## Documentation
Documentation is available online at https://moose-datatang.readthedocs.io/zh_CN/latest/ and in the `docs`
directory.


## Releases
You can find release notes at https://moose-datatang.readthedocs.io/zh_CN/latest/news.html

## Contributing
See https://moose-datatang.readthedocs.io/zh_CN/latest/contributing.html
